==> opendkim_2.0.1+dfsg.orig.tar.gz: opendkim-2.0.1/libopendkim/tests/t-test117.c <==
/*
**  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
**    All rights reserved.
**
**  Copyright (c) 2009, The OpenDKIM Project.  All rights reserved.
*/

#ifndef lint
static char t_test117_c_id[] = "@(#)$Id: t-test117.c,v 1.2 2009/12/08 19:14:27 cm-msk Exp $";
#endif /* !lint */

/* system includes */
#include <sys/types.h>
#include <assert.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>

/* libopendkim includes */
#include "../dkim-internal.h"
#include "t-testdata.h"

#define	MAXHEADER	4096

#define SIG2 "v=1; a=rsa-sha1; c=relaxed/simple; d=example.com; s=test;\r\n\tt=1172620939; bh=ll/0h2aWgG+D3ewmE4Y3pY7Ukz8=; h=Received:Received:\r\n\t Received:From:To:Date:Subject:Message-ID; b=bj9kVUbnBYfe9sVzH9lT45\r\n\tTFKO3eQnDbXLfgmgu/b5QgxcnhT9ojnV2IAM4KUO8+hOo5sDEu5Co/0GASH0vHpSV4P\r\n\t377Iwew3FxvLpHsVbVKgXzoKD4QSbHRpWNxyL6LypaaqFa96YqjXuYXr0vpb88hticn\r\n\t6I16//WThMz8fMU="

char *senderhdrs[] =
{
	"from",
	"sender",
	NULL
};

/*
**  MAIN -- program mainline
**
**  Parameters:
**  	The usual.
**
**  Return value:
**  	Exit status.
*/

int
main(int argc, char **argv)
{
#ifdef TEST_KEEP_FILES
	u_int flags;
#endif /* TEST_KEEP_FILES */
	u_int test_uint;
	u_int timeout;
	time_t fixed_time;
	time_t test_time;
	DKIM_STAT status;
	DKIM *dkim;
	DKIM_LIB *lib;
	char **testarray;
	dkim_query_t qtype = DKIM_QUERY_FILE;
	unsigned char hdr[MAXHEADER + 1];
	char path[MAXPATHLEN + 1];
	char *td = NULL;

	printf("*** general utility functions\n");

	/* instantiate the library */
	lib = dkim_init(NULL, NULL);
	assert(lib != NULL);

#ifdef TEST_KEEP_FILES
	/* set flags */
	flags = (DKIM_LIBFLAGS_TMPFILES|DKIM_LIBFLAGS_KEEPFILES);
	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_FLAGS, &flags,
	                    sizeof flags);
#endif /* TEST_KEEP_FILES */

	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_QUERYMETHOD,
	                    &qtype, sizeof qtype);
	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_QUERYINFO,
	                    KEYFILE, strlen(KEYFILE));

	/* exercise some dkim_options() stuff */
	status = dkim_options(lib, DKIM_OP_GETOPT, DKIM_OPTS_TMPDIR,
	                      path, sizeof path);
	assert(status == DKIM_STAT_OK);
	td = getenv("DKIM_TMPDIR");
	if (td == NULL || td[0] == '\0')
		td = DEFTMPDIR;
	assert(strcmp(path, td) == 0);

	fixed_time = 1172620939;
	status = dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_FIXEDTIME,
	                      &fixed_time, sizeof fixed_time);
	assert(status == DKIM_STAT_OK);
	status = dkim_options(lib, DKIM_OP_GETOPT, DKIM_OPTS_FIXEDTIME,
	                      &test_time, sizeof test_time);
	assert(status == DKIM_STAT_OK);
	assert(test_time == fixed_time);

	fixed_time = 300;
	status = dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_SIGNATURETTL,
	                      &fixed_time, sizeof fixed_time);
	assert(status == DKIM_STAT_OK);
	status = dkim_options(lib, DKIM_OP_GETOPT, DKIM_OPTS_SIGNATURETTL,
	                      &test_time, sizeof test_time);
	assert(status == DKIM_STAT_OK);
	assert(test_time == fixed_time);

	fixed_time = 600;
	status = dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_CLOCKDRIFT,
	                      &fixed_time, sizeof fixed_time);
	assert(status == DKIM_STAT_OK);
	status = dkim_options(lib, DKIM_OP_GETOPT, DKIM_OPTS_CLOCKDRIFT,
	                      &test_time, sizeof test_time);
	assert(status == DKIM_STAT_OK);
	assert(test_time == fixed_time);

	timeout = 5;
	status = dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_TIMEOUT,
	                      &timeout, sizeof timeout);
	assert(status == DKIM_STAT_OK);
	status = dkim_options(lib, DKIM_OP_GETOPT, DKIM_OPTS_TIMEOUT,
	                      &test_uint, sizeof test_uint);
	assert(status == DKIM_STAT_OK);
	assert(test_uint == timeout);

	status = dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_SENDERHDRS,
	                      senderhdrs, sizeof (char **));
	assert(status == DKIM_STAT_OK);
	status = dkim_options(lib, DKIM_OP_GETOPT, DKIM_OPTS_SENDERHDRS,
	                      &testarray, sizeof (char **));
	assert(status == DKIM_STAT_OK);
	assert(strcmp(testarray[0], senderhdrs[0]) == 0);
	assert(strcmp(testarray[1], senderhdrs[1]) == 0);
	assert(testarray[2] == NULL);

	dkim = dkim_verify(lib, JOBID, NULL, &status);
	assert(dkim != NULL);

	snprintf(hdr, sizeof hdr, "%s: %s", DKIM_SIGNHEADER, SIG2);
	status = dkim_header(dkim, hdr, strlen(hdr));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER01, strlen(HEADER01));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER02, strlen(HEADER02));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER03, strlen(HEADER03));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER04, strlen(HEADER04));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER05, strlen(HEADER05));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER06, strlen(HEADER06));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER07, strlen(HEADER07));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER08, strlen(HEADER08));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER09, strlen(HEADER09));
	assert(status == DKIM_STAT_OK);

	status = dkim_eoh(dkim);
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY00, strlen(BODY00));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY01, strlen(BODY01));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY01A, strlen(BODY01A));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01B, strlen(BODY01B));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01C, strlen(BODY01C));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01D, strlen(BODY01D));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01E, strlen(BODY01E));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY02, strlen(BODY02));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY04, strlen(BODY04));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY05, strlen(BODY05));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_eom(dkim, NULL);
	assert(status == DKIM_STAT_OK);

	assert(dkim_getmode(dkim) == DKIM_MODE_VERIFY);
	assert(strcmp(dkim_getdomain(dkim), DOMAIN2) == 0);
	assert(dkim_geterror(dkim) == NULL);

	status = dkim_free(dkim);
	assert(status == DKIM_STAT_OK);

	dkim_close(lib);

	return 0;
}

==> opendkim_2.4.2+dfsg.orig.tar.gz: opendkim-2.4.2+dfsg/libopendkim/tests/t-test117.c <==
/*
**  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
**    All rights reserved.
**
**  Copyright (c) 2009-2011, The OpenDKIM Project.  All rights reserved.
*/

#ifndef lint
static char t_test117_c_id[] = "@(#)$Id: t-test117.c,v 1.3 2010/07/23 01:54:29 cm-msk Exp $";
#endif /* !lint */

#include "build-config.h"

/* system includes */
#include <sys/types.h>
#include <assert.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>

#ifdef USE_GNUTLS
# include <gnutls/gnutls.h>
#endif /* USE_GNUTLS */

/* libopendkim includes */
#include "../dkim-internal.h"
#include "t-testdata.h"

#define	MAXHEADER	4096

#define SIG2 "v=1; a=rsa-sha1; c=relaxed/simple; d=example.com; s=test;\r\n\tt=1172620939; bh=ll/0h2aWgG+D3ewmE4Y3pY7Ukz8=; h=Received:Received:\r\n\t Received:From:To:Date:Subject:Message-ID; b=bj9kVUbnBYfe9sVzH9lT45\r\n\tTFKO3eQnDbXLfgmgu/b5QgxcnhT9ojnV2IAM4KUO8+hOo5sDEu5Co/0GASH0vHpSV4P\r\n\t377Iwew3FxvLpHsVbVKgXzoKD4QSbHRpWNxyL6LypaaqFa96YqjXuYXr0vpb88hticn\r\n\t6I16//WThMz8fMU="

char *senderhdrs[] =
{
	"from",
	"sender",
	NULL
};

/*
**  MAIN -- program mainline
**
**  Parameters:
**  	The usual.
**
**  Return value:
**  	Exit status.
*/

int
main(int argc, char **argv)
{
#ifdef TEST_KEEP_FILES
	u_int flags;
#endif /* TEST_KEEP_FILES */
	u_int test_uint;
	u_int timeout;
	uint64_t fixed_time;
	uint64_t test_time;
	DKIM_STAT status;
	DKIM *dkim;
	DKIM_LIB *lib;
	char **testarray;
	dkim_query_t qtype = DKIM_QUERY_FILE;
	unsigned char hdr[MAXHEADER + 1];
	char path[MAXPATHLEN + 1];
	char *td = NULL;

	printf("*** general utility functions\n");

#ifdef USE_GNUTLS
	(void) gnutls_global_init();
#endif /* USE_GNUTLS */

	/* instantiate the library */
	lib = dkim_init(NULL, NULL);
	assert(lib != NULL);

#ifdef TEST_KEEP_FILES
	/* set flags */
	flags = (DKIM_LIBFLAGS_TMPFILES|DKIM_LIBFLAGS_KEEPFILES);
	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_FLAGS, &flags,
	                    sizeof flags);
#endif /* TEST_KEEP_FILES */

	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_QUERYMETHOD,
	                    &qtype, sizeof qtype);
	(void) dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_QUERYINFO,
	                    KEYFILE, strlen(KEYFILE));

	/* exercise some dkim_options() stuff */
	status = dkim_options(lib, DKIM_OP_GETOPT, DKIM_OPTS_TMPDIR,
	                      path, sizeof path);
	assert(status == DKIM_STAT_OK);
	td = getenv("DKIM_TMPDIR");
	if (td == NULL || td[0] == '\0')
		td = DEFTMPDIR;
	assert(strcmp(path, td) == 0);

	fixed_time = 1172620939;
	status = dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_FIXEDTIME,
	                      &fixed_time, sizeof fixed_time);
	assert(status == DKIM_STAT_OK);
	status = dkim_options(lib, DKIM_OP_GETOPT, DKIM_OPTS_FIXEDTIME,
	                      &test_time, sizeof test_time);
	assert(status == DKIM_STAT_OK);
	assert(test_time == fixed_time);

	fixed_time = 300;
	status = dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_SIGNATURETTL,
	                      &fixed_time, sizeof fixed_time);
	assert(status == DKIM_STAT_OK);
	status = dkim_options(lib, DKIM_OP_GETOPT, DKIM_OPTS_SIGNATURETTL,
	                      &test_time, sizeof test_time);
	assert(status == DKIM_STAT_OK);
	assert(test_time == fixed_time);

	fixed_time = 600;
	status = dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_CLOCKDRIFT,
	                      &fixed_time, sizeof fixed_time);
	assert(status == DKIM_STAT_OK);
	status = dkim_options(lib, DKIM_OP_GETOPT, DKIM_OPTS_CLOCKDRIFT,
	                      &test_time, sizeof test_time);
	assert(status == DKIM_STAT_OK);
	assert(test_time == fixed_time);

	timeout = 5;
	status = dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_TIMEOUT,
	                      &timeout, sizeof timeout);
	assert(status == DKIM_STAT_OK);
	status = dkim_options(lib, DKIM_OP_GETOPT, DKIM_OPTS_TIMEOUT,
	                      &test_uint, sizeof test_uint);
	assert(status == DKIM_STAT_OK);
	assert(test_uint == timeout);

	status = dkim_options(lib, DKIM_OP_SETOPT, DKIM_OPTS_SENDERHDRS,
	                      senderhdrs, sizeof (char **));
	assert(status == DKIM_STAT_OK);
	status = dkim_options(lib, DKIM_OP_GETOPT, DKIM_OPTS_SENDERHDRS,
	                      &testarray, sizeof (char **));
	assert(status == DKIM_STAT_OK);
	assert(strcmp(testarray[0], senderhdrs[0]) == 0);
	assert(strcmp(testarray[1], senderhdrs[1]) == 0);
	assert(testarray[2] == NULL);

	dkim = dkim_verify(lib, JOBID, NULL, &status);
	assert(dkim != NULL);

	snprintf(hdr, sizeof hdr, "%s: %s", DKIM_SIGNHEADER, SIG2);
	status = dkim_header(dkim, hdr, strlen(hdr));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER01, strlen(HEADER01));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER02, strlen(HEADER02));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER03, strlen(HEADER03));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER04, strlen(HEADER04));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER05, strlen(HEADER05));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER06, strlen(HEADER06));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER07, strlen(HEADER07));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER08, strlen(HEADER08));
	assert(status == DKIM_STAT_OK);

	status = dkim_header(dkim, HEADER09, strlen(HEADER09));
	assert(status == DKIM_STAT_OK);

	status = dkim_eoh(dkim);
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY00, strlen(BODY00));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY01, strlen(BODY01));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY01A, strlen(BODY01A));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01B, strlen(BODY01B));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01C, strlen(BODY01C));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01D, strlen(BODY01D));
	assert(status == DKIM_STAT_OK);
	status = dkim_body(dkim, BODY01E, strlen(BODY01E));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY02, strlen(BODY02));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY04, strlen(BODY04));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY05, strlen(BODY05));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_body(dkim, BODY03, strlen(BODY03));
	assert(status == DKIM_STAT_OK);

	status = dkim_eom(dkim, NULL);
	assert(status == DKIM_STAT_OK);

	assert(dkim_getmode(dkim) == DKIM_MODE_VERIFY);
	assert(strcmp(dkim_getuser(dkim), USER) == 0);
	assert(strcmp(dkim_getdomain(dkim), DOMAIN2) == 0);
	assert(dkim_geterror(dkim) == NULL);

	status = dkim_free(dkim);
	assert(status == DKIM_STAT_OK);

	dkim_close(lib);

	return 0;
}
